==> jafuffy.0_5_0.zip: JaFuffy/Quellen/Java/jafuffy/bedienung/Kommentierung.java <==
/******************************************************************************
 ** $Id: Kommentierung.java 826 2015-11-29 22:56:05Z wmh $
 ** Diese Datei ist Bestandteil der Java-Quelltexte des Wrfelspiels JaFuffy.
 ** Lauffhig ab Java 6.
 ******************************************************************************
 ** Copyright (C) Wolfgang Hauck <wolfgang.hauck@3kelvin.de>
 ******************************************************************************
 ** This program is free software: you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation, either version 3 of the License, or
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************
 ** Die aktuellste Version von JaFuffy findet sich im Internet unter
 ** <http://jafuffy.3kelvin.de>.
 **
 ** Kommentare, Fehler oder Erweiterungswnsche bitte per E-Mail senden an
 ** <jafuffy@3kelvin.de>.
 ******************************************************************************/
package jafuffy.bedienung;

import jafuffy.logik.CEJaFuffy;
import jafuffy.logik.CEStatistik;
import jafuffy.logik.Statistik;
import jafuffy.logik.Statistik.Rang;

import java.util.ArrayList;

import javax.swing.ImageIcon;
import javax.swing.JOptionPane;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

/** Klasse zur Eingabe eines Kommentars fr die Bestenliste. */
@SuppressWarnings("serial")
public class Kommentierung extends JOptionPane implements ChangeListener {

    /** Icon fr Eintrag in Bestenlist. */
    private static final ImageIcon BESTER = Grafik.icon("Bester.png");
    /** Schttelgerusch. */
    private static final Geraeusch TADA = new Geraeusch("TaDa.wav");

    /** Spielplatz, in dem der Kommentierungsdialog zentriert wird. */
    private final Spielplatz spielplatz;

    /**
     * Konstruktor.
     *
     * @param spielplatz
     *            Spielplatz, in dem der Kommentierungsdialog zentriert wird.
     */
    public Kommentierung(Spielplatz spielplatz) {
        this.spielplatz = spielplatz;
    }

    /**
     * ChangeEvent eingetreten.
     *
     * @param ce
     *            nderungsereignis im Lebenslauf der Statistik.
     */
    @Override
    public void stateChanged(ChangeEvent ce) {
        if (CEJaFuffy.adressiert(ce, CEStatistik.class)) {
            CEJaFuffy<CEStatistik> cej = CEJaFuffy.ereignisbehaelter(ce);
            switch (cej.ereignis()) {
            case BESTER:
                Statistik statistik = (Statistik) ce.getSource();
                kommentiere(statistik.rangmerker());
            default:
            }
        }
    }

    /**
     * Kommentieren der neuen Bestenlisteneintrge.
     *
     * @param rangmerker
     *            Liste aller betroffenen Rnge
     */
    private void kommentiere(ArrayList<Rang> rangmerker) {
        Rang.Eintrag eintrag;
        String kommentar;
        for (Rang rang : rangmerker) {
            TADA.play();
            eintrag = rang.neuester();
            kommentar =
                    (String) showInputDialog(spielplatz, "Gratulation!\n" + eintrag.name()
                            + " ist auf Rang " + rang.rangnummer() + " der Bestenliste!\n\n"
                            + eintrag.name() + ",\ndiesen Erfolg kannst du hier kommentieren:",
                            "JaFuffy (Aufnahme in Bestenliste)", INFORMATION_MESSAGE, BESTER,
                            null, null);
            eintrag.kommentar(kommentar);
        }
    }
}

==> jafuffy.0_5_2.zip: JaFuffy/Quellen/Java/jafuffy/bedienung/Kommentierung.java <==
/******************************************************************************
 ** $Id: Kommentierung.java 1017 2016-05-28 20:35:09Z wmh $
 ** Diese Datei ist Bestandteil der Java-Quelltexte des Wrfelspiels JaFuffy.
 ** Lauffhig ab Java 7.
 ******************************************************************************
 ** Copyright (C) Wolfgang Hauck <wolfgang.hauck@3kelvin.de>
 ******************************************************************************
 ** This program is free software: you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation, either version 3 of the License, or
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************
 ** Die aktuellste Version von JaFuffy findet sich im Internet unter
 ** <http://jafuffy.3kelvin.de>.
 **
 ** Kommentare, Fehler oder Erweiterungswnsche bitte per E-Mail senden an
 ** <jafuffy@3kelvin.de>.
 ******************************************************************************/
package jafuffy.bedienung;

import jafuffy.logik.CEJaFuffy;
import jafuffy.logik.CEStatistik;
import jafuffy.logik.Statistik;
import jafuffy.logik.Statistik.Rang;

import java.util.ArrayList;

import javax.swing.ImageIcon;
import javax.swing.JOptionPane;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

/** Klasse zur Eingabe eines Kommentars fr die Bestenliste. */
@SuppressWarnings("serial")
public class Kommentierung extends JOptionPane implements ChangeListener {

    /** Icon fr Eintrag in Bestenlist. */
    private static final ImageIcon BESTER = Grafik.icon("Bester.png");
    /** Schttelgerusch. */
    private static final Geraeusch TADA = new Geraeusch("TaDa.wav");

    /** Spielplatz, in dem der Kommentierungsdialog zentriert wird. */
    private final Spielplatz spielplatz;

    /**
     * Konstruktor.
     *
     * @param spielplatz
     *            Spielplatz, in dem der Kommentierungsdialog zentriert wird.
     */
    public Kommentierung(Spielplatz spielplatz) {
        this.spielplatz = spielplatz;
    }

    /**
     * ChangeEvent eingetreten.
     *
     * @param ce
     *            nderungsereignis im Lebenslauf der Statistik.
     */
    @Override
    public void stateChanged(ChangeEvent ce) {
        if (CEJaFuffy.adressiert(ce, CEStatistik.class)) {
            CEJaFuffy<CEStatistik> cej = CEJaFuffy.ereignisbehaelter(ce);
            switch (cej.ereignis()) {
            case BESTER:
                Statistik statistik = (Statistik) ce.getSource();
                kommentiere(statistik.rangmerker());
            default:
            }
        }
    }

    /**
     * Kommentieren der neuen Bestenlisteneintrge.
     *
     * @param rangmerker
     *            Liste aller betroffenen Rnge
     */
    private void kommentiere(ArrayList<Rang> rangmerker) {
        Rang.Eintrag eintrag;
        String kommentar;
        for (Rang rang : rangmerker) {
            TADA.play();
            eintrag = rang.neuester();
            kommentar = (String) showInputDialog(spielplatz,
                    "Gratulation!\n" + eintrag.name() + " ist auf Rang " + rang.rangnummer() + " der Bestenliste!\n\n"
                            + eintrag.name() + ",\ndiesen Erfolg kannst du hier kommentieren:",
                    "JaFuffy (Aufnahme in Bestenliste)", INFORMATION_MESSAGE, BESTER, null, null);
            eintrag.kommentar(kommentar);
        }
    }
}
